﻿using Microsoft.VisualStudio.TestTools.UnitTesting;
using SampleApp;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Perforce.P4;

namespace SampleApp.Tests
{
    [TestClass()]
    public class MainFormTests
    {
        [TestMethod()]
        public void ConnectToServerTest()
        {
            Server server;
            Repository rep;
            Connection con;

            string uri = @"rsh:c:\test\p4d.exe -r C:\test -L log -i";

            Utilities utils = new Utilities();
            con = utils.ConnectToServer(uri, out server, out rep);

            Assert.IsNotNull(con);    
        }

        [TestMethod()]
        [ExpectedException(typeof(AssertFailedException))]
        public void ConnectToServerTestFalse()
        {
            Server server;
            Repository rep;
            Connection con;

            string uri = "FalseUri";

            Utilities utils = new Utilities();
            con = utils.ConnectToServer(uri, out server, out rep);

            Assert.IsNotNull(con);
        }

        [TestMethod()]
        public void LoginToServerTest()
        {
            Server server;
            Repository rep;
            Connection con;
            Credential cred;

            string uri = @"rsh:c:\test\p4d.exe -r C:\test -L log -i";
            string userName = "Paul_Arva";
            string clientName = "Paul_Arva_SampleApp";
            string password = "Perpass1";

            Utilities utils = new Utilities();
            con = utils.ConnectToServer(uri, out server, out rep);
            utils.LoginToServer(con, userName, clientName, password, out cred);

            Assert.IsNotNull(cred);
        }

        [TestMethod()]
        [ExpectedException(typeof(AssertFailedException))]
        public void LoginToServerTestFalse()
        {
            Server server;
            Repository rep;
            Connection con;
            Credential cred;

            string uri = @"rsh:c:\test\p4d.exe -r C:\test -L log -i";
            string userName = "FalseUserName";
            string clientName = "FalseClientName";
            string password = "FalsePass";

            Utilities utils = new Utilities();
            con = utils.ConnectToServer(uri, out server, out rep);
            utils.LoginToServer(con, userName, clientName, password, out cred);

            Assert.IsNotNull(cred);
        }

        [TestMethod()]
        public void GetClientMapTest()
        {
            Server server;
            Repository rep;
            Connection con;
            Credential cred;
            Client client;

            string uri = @"rsh:c:\test\p4d.exe -r C:\test -L log -i";
            string userName = "Paul_Arva";
            string clientName = "Paul_Arva_SampleApp";
            string password = "Perpass1";

            Utilities utils = new Utilities();
            con = utils.ConnectToServer(uri, out server, out rep);
            utils.LoginToServer(con, userName, clientName, password, out cred);
            client = utils.GetClientMap(clientName, rep);

            Assert.IsNotNull(client);
        }

        [TestMethod()]
        [ExpectedException(typeof(AssertFailedException))]
        public void GetClientMapTestFalse()
        {
            Server server;
            Repository rep;
            Connection con;
            Credential cred;
            Client client;

            string uri = @"rsh:c:\test\p4d.exe -r C:\test -L log -i";
            string userName = "Paul_Arva";
            string clientName = "FalseClientName";
            string password = "Perpass1";

            Utilities utils = new Utilities();
            con = utils.ConnectToServer(uri, out server, out rep);
            utils.LoginToServer(con, userName, clientName, password, out cred);
            client = utils.GetClientMap(clientName, rep);

            Assert.IsNotNull(client);
        }

        [TestMethod()]
        public void SubmitClientMapTest()
        {
            Server server;
            Repository rep;
            Connection con;
            Credential cred;
            Client client;
            Client resultantClient;

            string uri = @"rsh:c:\test\p4d.exe -r C:\test -L log -i";
            string userName = "Paul_Arva";
            string clientName = "Paul_Arva_SampleApp";
            string password = "Perpass1";

            Utilities utils = new Utilities();
            con = utils.ConnectToServer(uri, out server, out rep);
            utils.LoginToServer(con, userName, clientName, password, out cred);
            client = utils.GetClientMap(clientName, rep);
            resultantClient = utils.SubmitClientMap(client, rep);

            Assert.IsNotNull(resultantClient);
        }

        [TestMethod()]
        [ExpectedException(typeof(AssertFailedException))]
        public void SubmitClientMapTestFalse()
        {
            Server server;
            Repository rep;
            Connection con;
            Credential cred;
            Client client;
            Client resultantClient;

            string uri = @"rsh:c:\test\p4d.exe -r C:\test -L log -i";
            string userName = "Paul_Arva";
            string clientName = "FalseClientName";
            string password = "Perpass1";

            Utilities utils = new Utilities();
            con = utils.ConnectToServer(uri, out server, out rep);
            utils.LoginToServer(con, userName, clientName, password, out cred);
            client = utils.GetClientMap(clientName, rep);
            resultantClient = utils.SubmitClientMap(client, rep);

            Assert.IsNotNull(resultantClient);
        }
    }
}